==> jc-1.4.0.tar.gz: java/lang/ClassLoader__241.h <==
// final class java.lang.ClassLoader$1

// class file dependencies
// @dep_class 26b8d7b7a241db31 java_lang_ClassLoader
// @dep_class 6a3037e6b5bfd253 java_lang_ClassLoader__241
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7475ebc6fa299754 java_net_URLClassLoader
// @dep_class 50a05c4401dcb8be java_security_SecureClassLoader

// header file dependencies
// @dep_header java_net_URLClassLoader

#include "java/net/URLClassLoader.h"

#ifndef _JC_java_lang_ClassLoader__241_H_
#define _JC_java_lang_ClassLoader__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ClassLoader__241$sub_refs	_jc_java_lang_ClassLoader__241$sub_refs;
typedef struct _jc_java_lang_ClassLoader__241$sub_nonrefs	_jc_java_lang_ClassLoader__241$sub_nonrefs;
typedef struct _jc_java_lang_ClassLoader__241$refs	_jc_java_lang_ClassLoader__241$refs;
typedef struct _jc_java_lang_ClassLoader__241$nonrefs	_jc_java_lang_ClassLoader__241$nonrefs;
typedef struct _jc_java_lang_ClassLoader__241$object	_jc_java_lang_ClassLoader__241$object;

typedef const struct _jc_java_lang_ClassLoader__241$vmethods	_jc_java_lang_ClassLoader__241$vmethods;
typedef const struct _jc_java_lang_ClassLoader__241$vtable	_jc_java_lang_ClassLoader__241$vtable;
typedef const struct _jc_java_lang_ClassLoader__241$vtype	_jc_java_lang_ClassLoader__241$vtype;

// Constructors
extern void _jc_java_lang_ClassLoader__241$method$_init$dac6f9c2ae72ecdf(_jc_env *, struct _jc_java_lang_ClassLoader__241$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_lang_ClassLoader__241$method$loadClass$6acbb472c465f6c2(_jc_env *, struct _jc_java_lang_ClassLoader__241$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ClassLoader__241$method_info$loadClass$6acbb472c465f6c2;

// Virtual methods structure
struct _jc_java_lang_ClassLoader__241$vmethods {
	struct _jc_java_lang_Class$object	*(*loadClass$6acbb472c465f6c2)(_jc_env *, struct _jc_java_lang_ClassLoader__241$object *, struct _jc_java_lang_String$object *, jboolean);
};

// Vtable
struct _jc_java_lang_ClassLoader__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ClassLoader$vmethods	java_lang_ClassLoader;
	_jc_java_security_SecureClassLoader$vmethods	java_security_SecureClassLoader;
	_jc_java_net_URLClassLoader$vmethods	java_net_URLClassLoader;
	_jc_java_lang_ClassLoader__241$vmethods	java_lang_ClassLoader__241;
};

// Vtype
struct _jc_java_lang_ClassLoader__241$vtype {
	_jc_type			type;
	_jc_java_lang_ClassLoader__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ClassLoader__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ClassLoader__241$refs {
    _jc_java_lang_ClassLoader__241$sub_refs	java_lang_ClassLoader__241;
    _jc_java_net_URLClassLoader$sub_refs	java_net_URLClassLoader;
    _jc_java_security_SecureClassLoader$sub_refs	java_security_SecureClassLoader;
    _jc_java_lang_ClassLoader$sub_refs	java_lang_ClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ClassLoader__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ClassLoader__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ClassLoader$sub_nonrefs	java_lang_ClassLoader;
    _jc_java_security_SecureClassLoader$sub_nonrefs	java_security_SecureClassLoader;
    _jc_java_net_URLClassLoader$sub_nonrefs	java_net_URLClassLoader;
    _jc_java_lang_ClassLoader__241$sub_nonrefs	java_lang_ClassLoader__241;
};

// Object instance structure
struct _jc_java_lang_ClassLoader__241$object {
	_jc_java_lang_ClassLoader__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ClassLoader__241$vtype	*vtype;
	_jc_java_lang_ClassLoader__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ClassLoader__241$vtype _jc_java_lang_ClassLoader__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ClassLoader__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ClassLoader__241$class_object;

#endif	/* _JC_java_lang_ClassLoader__241_H_ */

==> jc-1.4.5.tar.gz: java/lang/ClassLoader__241.h <==
// final class java.lang.ClassLoader$1

// class file dependencies
// @dep_class 58c6b9c5ce1fc756 java_lang_ClassLoader
// @dep_class 1f9f5e567110d7de java_lang_ClassLoader__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f9753be73caf5b06 java_net_URLClassLoader
// @dep_class 50a05c4401dcb8be java_security_SecureClassLoader

// header file dependencies
// @dep_header java_net_URLClassLoader

#include "java/net/URLClassLoader.h"

#ifndef _JC_java_lang_ClassLoader__241_H_
#define _JC_java_lang_ClassLoader__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ClassLoader__241$sub_refs	_jc_java_lang_ClassLoader__241$sub_refs;
typedef struct _jc_java_lang_ClassLoader__241$sub_nonrefs	_jc_java_lang_ClassLoader__241$sub_nonrefs;
typedef struct _jc_java_lang_ClassLoader__241$refs	_jc_java_lang_ClassLoader__241$refs;
typedef struct _jc_java_lang_ClassLoader__241$nonrefs	_jc_java_lang_ClassLoader__241$nonrefs;
typedef struct _jc_java_lang_ClassLoader__241$object	_jc_java_lang_ClassLoader__241$object;

typedef const struct _jc_java_lang_ClassLoader__241$vmethods	_jc_java_lang_ClassLoader__241$vmethods;
typedef const struct _jc_java_lang_ClassLoader__241$vtable	_jc_java_lang_ClassLoader__241$vtable;
typedef const struct _jc_java_lang_ClassLoader__241$vtype	_jc_java_lang_ClassLoader__241$vtype;

// Constructors
extern void _jc_java_lang_ClassLoader__241$method$_init$dac6f9c2ae72ecdf(_jc_env *, struct _jc_java_lang_ClassLoader__241$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_lang_ClassLoader__241$method$loadClass$6acbb472c465f6c2(_jc_env *, struct _jc_java_lang_ClassLoader__241$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ClassLoader__241$method_info$loadClass$6acbb472c465f6c2;

// Virtual methods structure
struct _jc_java_lang_ClassLoader__241$vmethods {
	struct _jc_java_lang_Class$object	*(*loadClass$6acbb472c465f6c2)(_jc_env *, struct _jc_java_lang_ClassLoader__241$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ClassLoader__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ClassLoader$vmethods	java_lang_ClassLoader;
	_jc_java_security_SecureClassLoader$vmethods	java_security_SecureClassLoader;
	_jc_java_net_URLClassLoader$vmethods	java_net_URLClassLoader;
	_jc_java_lang_ClassLoader__241$vmethods	java_lang_ClassLoader__241;
};

// Vtype
struct _jc_java_lang_ClassLoader__241$vtype {
	_jc_type			type;
	_jc_java_lang_ClassLoader__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ClassLoader__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ClassLoader__241$refs {
    _jc_java_lang_ClassLoader__241$sub_refs	java_lang_ClassLoader__241;
    _jc_java_net_URLClassLoader$sub_refs	java_net_URLClassLoader;
    _jc_java_security_SecureClassLoader$sub_refs	java_security_SecureClassLoader;
    _jc_java_lang_ClassLoader$sub_refs	java_lang_ClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ClassLoader__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ClassLoader__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ClassLoader$sub_nonrefs	java_lang_ClassLoader;
    _jc_java_security_SecureClassLoader$sub_nonrefs	java_security_SecureClassLoader;
    _jc_java_net_URLClassLoader$sub_nonrefs	java_net_URLClassLoader;
    _jc_java_lang_ClassLoader__241$sub_nonrefs	java_lang_ClassLoader__241;
};

// Object instance structure
struct _jc_java_lang_ClassLoader__241$object {
	_jc_java_lang_ClassLoader__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ClassLoader__241$vtype	*vtype;
	_jc_java_lang_ClassLoader__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ClassLoader__241$vtype _jc_java_lang_ClassLoader__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ClassLoader__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ClassLoader__241$class_object;

#endif	/* _JC_java_lang_ClassLoader__241_H_ */
